; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
[Command]
name = "ESTornado"
command = ~D, DB, B, a+b
time = 10

[Command]
name = "ESTornado"
command = ~D, DB, B, a+c
time = 10

[Command]
name = "ESTornado"
command = ~D, DB, B, b+c
time = 10

[Command]
name = "Phoenix"
command = ~D, DB, B, DB, F, a+b
time = 30

[Command]
name = "Phoenix"
command = ~D, DB, B, DB, F, a+c
time = 30

[Command]
name = "Phoenix"
command = ~D, DB, B, DB, F, c+b
time = 30

[Command]
name = "ESFireball"
command = ~30$B, F, a+b
time = 10

[Command]
name = "ESFireball"
command = ~30$B, F, a+c
time = 10

[Command]
name = "ESFireball"
command = ~30$B, F, c+b
time = 10

[Command]
name = "ESBeam"
command = ~D, DF, F, a+b
time = 30

[Command]
name = "ESBeam"
command = ~D, DF, F, a+c
time = 30

[Command]
name = "ESBeam"
command = ~D, DF, F, c+b
time = 30

;-| Special Motions |------------------------------------------------------
;-----------------
[Command]
name = "Beam"
command = ~D, DF, F, a
time = 30

[Command]
name = "Beam"
command = ~D, DF, F, b
time = 30

[Command]
name = "Beam"
command = ~D, DF, F, c
time = 30

[Command]
name = "Fireball"
command = ~30$B, F, a
time = 10

[Command]
name = "Fireball"
command = ~30$B, F, b
time = 10

[Command]
name = "Fireball"
command = ~30$B, F, c
time = 10

[Command]
name = "Rick"
command = ~F, D, DF, a
time = 30

[Command]
name = "Rick"
command = ~F, D, DF, b
time = 30

[Command]
name = "Rick"
command = ~F, D, DF, c
time = 30

[Command]
name = "Tornado"
command = ~D, DB, B, a
time = 30

[Command]
name = "Tornado"
command = ~D, DB, B, b
time = 30

[Command]
name = "Tornado"
command = ~D, DB, B, c
time = 30

[Command]
name = "Kine"
command = F, B, a
time = 30

[Command]
name = "Kine"
command = F, B, b
time = 30

[Command]
name = "Kine"
command = F, B, c
time = 30

[Command]
name = "Coo"
command = ~U, UB, B, a
time = 30

[Command]
name = "Coo"
command = ~U, UB, B, b
time = 30

[Command]
name = "Coo"
command = ~U, UB, B, c
time = 30

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; ES Tornado
[State -1]
type = ChangeState
value = 3400
triggerall = command = "ESTornado"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 4
trigger3 = Stateno = 200
trigger3 = MoveContact = 1
trigger3 = Time >= 6
trigger4 = Stateno = 210
trigger4 = MoveContact = 1
trigger4 = Time >= 8
trigger5 = statetype = A
trigger5 = ctrl = 1
trigger6 = Stateno = 601
trigger6 = MoveContact = 1
trigger7 = Stateno = 600
trigger7 = MoveContact = 1

;Phoenix Flattener
[State -1]
type = Changestate
value = 7030
triggerall = command = "Phoenix"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1

;ESFireball
[State -1]
type = Changestate
value = 3100
triggerall = command = "ESFireball"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = A
trigger2 = ctrl = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 800
trigger5 = statetype = S
trigger5 = ctrl = 1

;ES Guard Reversal
[State -1]
type = ChangeState
value = 3205
triggerall = command = "ESBeam"
triggerall = power >= 1000
trigger1 = stateno = 153
trigger2 = stateno = 151
trigger3 = stateno = 150
trigger4 = stateno = 152

;---------------------------------------------------------------------------
; Coo
[State -1]
type = ChangeState
value = 1700
triggerall = command = "Coo"
trigger1 = statetype = A
trigger1 = ctrl = 1

; Kine
[State -1]
type = ChangeState
value = 1500
triggerall = command = "Kine"
trigger1 = statetype = S
trigger1 = ctrl = 1

; Tornado
[State -1]
type = ChangeState
value = 1400
triggerall = command = "Tornado"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 4
trigger3 = Stateno = 200
trigger3 = MoveContact = 1
trigger3 = Time >= 6
trigger4 = Stateno = 210
trigger4 = MoveContact = 1
trigger4 = Time >= 8
trigger5 = statetype = A
trigger5 = ctrl = 1
trigger6 = Stateno = 601
trigger6 = MoveContact = 1
trigger7 = Stateno = 600
trigger7 = MoveContact = 1

; Rick
[State -1]
type = ChangeState
value = 1300
triggerall = command = "Rick"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Fireball
[State -1]
type = Changestate
value = 1100
triggerall = command = "Fireball"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 4
trigger3 = Stateno = 200
trigger3 = MoveContact = 1
trigger3 = Time >= 6
trigger4 = Stateno = 210
trigger4 = MoveContact = 1
trigger4 = Time >= 8
trigger5 = statetype = A
trigger5 = ctrl = 1

;Guard Reversal
[State -1]
type = ChangeState
value = 1001
triggerall = command = "Beam"
trigger1 = stateno = 153
trigger2 = stateno = 151
trigger3 = stateno = 150
trigger4 = stateno = 152

;Parasol
[State -1]
type = ChangeState
value = 201
triggerall = command = "c"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Parasol
[State -1]
type = ChangeState
value = 601
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_b";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_b";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_b";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"


;===========================================================================
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = "a";Place name of command here
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 6

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 4
trigger3 = Stateno = 200
trigger3 = MoveContact = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 4
trigger3 = Stateno = 200
trigger3 = MoveContact = 1
trigger3 = Time >= 6

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = Stateno = 201
trigger2 = MoveContact = 1
trigger2 = Time >= 4
trigger3 = Stateno = 200
trigger3 = MoveContact = 1
trigger3 = Time >= 6

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = Stateno = 601
trigger2 = MoveContact = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Taunt
[State -1]
type = ChangeState
value = 800
triggerall = command = "s"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Kirby made by Jared (whipped@mistrust.com)